==> qtjambi-nfc-debuginfo-macos-5.15.20.jar: sources/QtJambiNfc/QNdefFilter_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtNfc/qndeffilter.h>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtNfc/qndefrecord.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QNdefFilter(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QNdefFilter")
    QNdefFilter *_ptr = reinterpret_cast<QNdefFilter *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QNdefFilter()
void __qt_construct_QNdefFilter(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QNdefFilter()")
    Q_UNUSED(__java_arguments)
    QNdefFilter *__qt_this = new(__qtjambi_ptr) QNdefFilter();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QNdefFilter::QNdefFilter()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_initialize_1native__Lio_qt_nfc_QNdefFilter_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNdefFilter::QNdefFilter()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QNdefFilter, sizeof(QNdefFilter), typeid(QNdefFilter), false, &deleter_QNdefFilter, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QNdefFilter(QNdefFilter)
void __qt_construct_QNdefFilter_cref_QNdefFilter(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QNdefFilter(QNdefFilter)")
    jobject other0 = __java_arguments[0].l;
    const QNdefFilter& __qt_other0 = qtjambi_cast<const QNdefFilter& >(__jni_env, other0);
    QNdefFilter *__qt_this = new(__qtjambi_ptr) QNdefFilter(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QNdefFilter::QNdefFilter(QNdefFilter)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_initialize_1native__Lio_qt_nfc_QNdefFilter_2Lio_qt_nfc_QNdefFilter_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNdefFilter::QNdefFilter(QNdefFilter)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QNdefFilter_cref_QNdefFilter, sizeof(QNdefFilter), typeid(QNdefFilter), false, &deleter_QNdefFilter, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QNdefFilter
void __qt_destruct_QNdefFilter(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QNdefFilter")
    reinterpret_cast<QNdefFilter*>(ptr)->~QNdefFilter();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QNdefFilter::appendRecord(QNdefFilter::Record)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_appendRecord_1native_1cref_1QNdefFilter_1Record__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID record0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QNdefFilter *__qt_this = QtJambiAPI::objectFromNativeId<QNdefFilter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNdefFilter::appendRecord(QNdefFilter::Record)", __qt_this)
        const QNdefFilter::Record& __qt_record0 = QtJambiAPI::valueReferenceFromNativeId<QNdefFilter::Record>(record0);
        __qt_this->appendRecord(__qt_record0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QNdefFilter::appendRecord(QNdefRecord::TypeNameFormat,QByteArray,uint,uint)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_appendRecord_1native_1QNdefRecord_1TypeNameFormat_1cref_1QByteArray_1unsigned_1int_1unsigned_1int__JIJII)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint typeNameFormat0,
 QtJambiNativeID type1,
 jint min2,
 jint max3)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QNdefFilter *__qt_this = QtJambiAPI::objectFromNativeId<QNdefFilter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNdefFilter::appendRecord(QNdefRecord::TypeNameFormat,QByteArray,uint,uint)", __qt_this)
        QNdefRecord::TypeNameFormat __qt_typeNameFormat0 = qtjambi_cast<QNdefRecord::TypeNameFormat>(__jni_env, typeNameFormat0);
        const QByteArray& __qt_type1 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(type1);
        __qt_this->appendRecord(QNdefRecord::TypeNameFormat(__qt_typeNameFormat0), __qt_type1, static_cast<unsigned int>(min2), static_cast<unsigned int>(max3));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QNdefFilter::clear()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_clear_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QNdefFilter *__qt_this = QtJambiAPI::objectFromNativeId<QNdefFilter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNdefFilter::clear()", __qt_this)
        __qt_this->clear();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QNdefFilter::operator=(QNdefFilter)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_assign_1native_1cref_1QNdefFilter__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QNdefFilter *__qt_this = QtJambiAPI::objectFromNativeId<QNdefFilter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNdefFilter::operator=(QNdefFilter)", __qt_this)
        const QNdefFilter& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QNdefFilter>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QNdefFilter::orderMatch()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_orderMatch_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QNdefFilter *__qt_this = QtJambiAPI::objectFromNativeId<QNdefFilter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNdefFilter::orderMatch()const", __qt_this)
        __java_return_value = __qt_this->orderMatch();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNdefFilter::recordAt(int)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_recordAt_1native_1int_1constfct__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint i0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QNdefFilter *__qt_this = QtJambiAPI::objectFromNativeId<QNdefFilter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNdefFilter::recordAt(int)const", __qt_this)
        QNdefFilter::Record __qt_return_value = __qt_this->recordAt(static_cast<int>(i0));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNdefFilter::recordCount()const
extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_recordCount_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jint __java_return_value{0};
    QTJAMBI_TRY {
        const QNdefFilter *__qt_this = QtJambiAPI::objectFromNativeId<QNdefFilter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNdefFilter::recordCount()const", __qt_this)
        __java_return_value = __qt_this->recordCount();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNdefFilter::setOrderMatch(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_setOrderMatch_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean on0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QNdefFilter *__qt_this = QtJambiAPI::objectFromNativeId<QNdefFilter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNdefFilter::setOrderMatch(bool)", __qt_this)
        __qt_this->setOrderMatch(static_cast<bool>(on0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QNdefFilter *__qt_this = QtJambiAPI::objectFromNativeId<QNdefFilter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QNdefFilter(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QNdefFilter>("QNdefFilter", "io/qt/nfc/QNdefFilter");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QNdefFilter, {
        ConstructorInfo(&__qt_construct_QNdefFilter, nullptr)
       ,ConstructorInfo(&__qt_construct_QNdefFilter_cref_QNdefFilter, "Lio/qt/nfc/QNdefFilter;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QNdefFilter);
    registerMetaType<QNdefFilter>("QNdefFilter");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-nfc-debuginfo-macos-6.5.4.jar: sources/QtJambiNfc/QNdefFilter_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtNfc/qndeffilter.h>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtNfc/qndefmessage.h>
#include <QtNfc/qndefrecord.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QNdefFilter(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QNdefFilter")
    QNdefFilter *_ptr = reinterpret_cast<QNdefFilter *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QNdefFilter()
void __qt_construct_QNdefFilter_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QNdefFilter()")
    Q_UNUSED(__java_arguments)
    QNdefFilter *__qt_this = new(__qtjambi_ptr) QNdefFilter();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QNdefFilter(QNdefFilter)
void __qt_construct_QNdefFilter_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QNdefFilter(QNdefFilter)")
    jobject other0 = __java_arguments[0].l;
    const QNdefFilter& __qt_other0 = qtjambi_cast<const QNdefFilter& >(__jni_env, other0);
    QNdefFilter *__qt_this = new(__qtjambi_ptr) QNdefFilter(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QNdefFilter
void __qt_destruct_QNdefFilter(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QNdefFilter")
    reinterpret_cast<QNdefFilter*>(ptr)->~QNdefFilter();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QNdefFilter::QNdefFilter()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_initialize_1native__Lio_qt_nfc_QNdefFilter_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNdefFilter::QNdefFilter()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QNdefFilter_0, sizeof(QNdefFilter), typeid(QNdefFilter), false, &deleter_QNdefFilter, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QNdefFilter::QNdefFilter(QNdefFilter)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_initialize_1native__Lio_qt_nfc_QNdefFilter_2Lio_qt_nfc_QNdefFilter_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QNdefFilter::QNdefFilter(QNdefFilter)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QNdefFilter_1, sizeof(QNdefFilter), typeid(QNdefFilter), false, &deleter_QNdefFilter, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QNdefFilter::appendRecord(QNdefFilter::Record)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_appendRecord_1native_1cref_1QNdefFilter_1Record__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID record0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QNdefFilter *__qt_this = QtJambiAPI::objectFromNativeId<QNdefFilter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNdefFilter::appendRecord(QNdefFilter::Record)", __qt_this)
        const QNdefFilter::Record& __qt_record0 = QtJambiAPI::valueReferenceFromNativeId<QNdefFilter::Record>(record0);
        __java_return_value = __qt_this->appendRecord(__qt_record0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNdefFilter::appendRecord(QNdefRecord::TypeNameFormat,QByteArray,uint,uint)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_appendRecord_1native_1QNdefRecord_1TypeNameFormat_1cref_1QByteArray_1unsigned_1int_1unsigned_1int__JIJII)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint typeNameFormat0,
 QtJambiNativeID type1,
 jint min2,
 jint max3)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QNdefFilter *__qt_this = QtJambiAPI::objectFromNativeId<QNdefFilter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNdefFilter::appendRecord(QNdefRecord::TypeNameFormat,QByteArray,uint,uint)", __qt_this)
        QNdefRecord::TypeNameFormat __qt_typeNameFormat0 = qtjambi_cast<QNdefRecord::TypeNameFormat>(__jni_env, typeNameFormat0);
        const QByteArray& __qt_type1 = QtJambiAPI::valueReferenceFromNativeId<QByteArray>(type1);
        __java_return_value = __qt_this->appendRecord(QNdefRecord::TypeNameFormat(__qt_typeNameFormat0), __qt_type1, static_cast<unsigned int>(min2), static_cast<unsigned int>(max3));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNdefFilter::clear()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_clear_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QNdefFilter *__qt_this = QtJambiAPI::objectFromNativeId<QNdefFilter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNdefFilter::clear()", __qt_this)
        __qt_this->clear();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QNdefFilter::match(QNdefMessage)const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_match_1native_1cref_1QNdefMessage_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID message0)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QNdefFilter *__qt_this = QtJambiAPI::objectFromNativeId<QNdefFilter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNdefFilter::match(QNdefMessage)const", __qt_this)
        const QNdefMessage& __qt_message0 = QtJambiAPI::valueReferenceFromNativeId<QNdefMessage>(message0);
        __java_return_value = __qt_this->match(__qt_message0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNdefFilter::operator=(QNdefFilter)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_assign_1native_1cref_1QNdefFilter__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QNdefFilter *__qt_this = QtJambiAPI::objectFromNativeId<QNdefFilter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNdefFilter::operator=(QNdefFilter)", __qt_this)
        const QNdefFilter& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QNdefFilter>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QNdefFilter::orderMatch()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_orderMatch_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QNdefFilter *__qt_this = QtJambiAPI::objectFromNativeId<QNdefFilter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNdefFilter::orderMatch()const", __qt_this)
        __java_return_value = __qt_this->orderMatch();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNdefFilter::recordAt(qsizetype)const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_recordAt_1native_1qsizetype_1constfct__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jlong i0)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QNdefFilter *__qt_this = QtJambiAPI::objectFromNativeId<QNdefFilter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNdefFilter::recordAt(qsizetype)const", __qt_this)
        QNdefFilter::Record __qt_return_value = __qt_this->recordAt(static_cast<qsizetype>(i0));
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNdefFilter::recordCount()const
extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_recordCount_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        const QNdefFilter *__qt_this = QtJambiAPI::objectFromNativeId<QNdefFilter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNdefFilter::recordCount()const", __qt_this)
        qsizetype __qt_return_value = __qt_this->recordCount();
        __java_return_value = jlong(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QNdefFilter::setOrderMatch(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_setOrderMatch_1native_1bool__JZ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jboolean on0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QNdefFilter *__qt_this = QtJambiAPI::objectFromNativeId<QNdefFilter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QNdefFilter::setOrderMatch(bool)", __qt_this)
        __qt_this->setOrderMatch(static_cast<bool>(on0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_nfc_QNdefFilter_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QNdefFilter *__qt_this = QtJambiAPI::objectFromNativeId<QNdefFilter>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QNdefFilter(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QNdefFilter>("QNdefFilter", "io/qt/nfc/QNdefFilter");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QNdefFilter, {
        ConstructorInfo(&__qt_construct_QNdefFilter_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QNdefFilter_1, "Lio/qt/nfc/QNdefFilter;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QNdefFilter);
    registerMetaType<QNdefFilter>("QNdefFilter");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
